@@ -389,7 +389,8 @@ class MessageBuffer:
         for (offset, setid, setlen) in self.setlist:
             setend = offset + setlen
             offset += _sethdr_st.size # skip set header in decode
-            if setid == 2 or setid == 3:
+            if setid == template.TEMPLATE_SET_ID or\
+               setid == template.OPTIONS_SET_ID:
                 while offset < setend:
                     (tmpl, offset) = template.decode_template_from(
                                               self.mbuf, offset, setid)
@@ -724,18 +725,13 @@ class MessageBuffer:
         """
         self.export_record(rec, template.Template.encode_namedict_to)
     
-    def export_tuple(self, rec, ielist = None):
+    def export_tuple(self, rec):
         """
         Export a record to the message, using the template for the current Set
-        ID. The record is a tuple of values, in template order by default.
-        If ielist is given, the tuple is in the order if IEs in that list
-        instead. The tuple must contain one value for each IE in the template;
-        values for IEs in the ielist not in the template will be ignored.
+        ID. The record is a tuple of values in template order.
         
-        :param rec: the record to export, as a tuple
-        :param ielist: optional information element list describing the order
-                       of the rec tuple
+        :param rec: the record to export, as a tuple in template order.
         :raises: EndOfMessage
         
         """       
-        self.export_record(rec, template.Template.encode_tuple_to, ielist)
\ No newline at end of file
+        self.export_record(rec, template.Template.encode_tuple_to)
\ No newline at end of file
