@@ -63,6 +63,7 @@ class TemplatePackingPlan:
     def __init__(self, tmpl, indices):
         self.tmpl = tmpl
         self.indices = indices
+        self.ranks = sorted(range(len(indices)), key=indices.__getitem__)
         self.valenc = []
         self.valdec = []
                 
@@ -207,9 +208,11 @@ class Template:
             packplan = self.packplan
             
         (vals, offset) = self.decode_from(buf, offset, packplan = packplan)
+        
+        outvals = tuple(v for i,v in sorted(zip(packplan.ranks, vals)))
 
         # re-sort values in same order as packplan indices
-        return (tuple(v for i,v in sorted(zip(packplan.indices, vals))), offset)
+        return (outvals, offset)
         
     def encode_to(self, buf, offset, vals, packplan = None):
         """Encodes a record from a tuple containing values in template order"""
@@ -255,18 +258,11 @@ class Template:
         
     def encode_tuple_to(self, buf, offset, rec, recinf = None):
         """
-        Encodes a record from a tuple containing values
-        ordered as the IEs in the InformationElementList given as recinf.
-        If recinf is not given, assumes the tuple contains all
-        IEs in the template in template order.
+        Encodes a record from a tuple containing values ordered as the IEs 
+        in the template.
          
         """
-        if recinf:
-            sortrec = (v for i, v in sorted(zip(packplan.indices, rec)))
-            return self.encode_to(buf, offset, sortrec,
-                                  self.packplan_for_ielist(recinf))
-        else:
-            return self.encode_to(buf, offset, rec)
+        return self.encode_to(buf, offset, rec)
     
     def encode_template_to(self, buf, offset, setid):
         """
@@ -359,19 +355,20 @@ def decode_template_from(buf, offset, setid):
     return (tmpl, offset)
     
 def from_ielist(tid, ielist):
-    """
-    Create a template from a template ID and an information element list
-    (itself available from :func:`ipfix.ie.spec_list`).
-    
-    :param tid: Template ID, must be between 256 and 65535.
-    :param ielist: List of Information Elements for the Template, see
-                   :func:`ipfix.ie.spec_list`.
-    :return: A new Template, ready to use for writing to a Message
-              
-    """
     
     tmpl = Template(tid, ielist)
     
     tmpl.finalize()
     
     return tmpl
+
+def for_specs(tid, *specs):
+    """
+    Create a template from a template ID and a list of IESpecs
+    
+    :param tid: Template ID, must be between 256 and 65535.
+    :param *specs: List of IESpecs 
+    :return: A new Template, ready to use for writing to a Message
+              
+    """
+    return from_ielist(tid, ie.spec_list(specs))
